var _ogre_d3_d9_render_system_8h =
[
    [ "Ogre::D3D9RenderSystem", "class_ogre_1_1_d3_d9_render_system.html", "class_ogre_1_1_d3_d9_render_system" ],
    [ "MAX_LIGHTS", "_ogre_d3_d9_render_system_8h.html#a737b417f16ea225cf15e8d4c23df53dc", null ]
];